package com.liu.demo.config;

import com.liu.demo.interceptor.RequestLogInterceptor;
import jakarta.annotation.Resource;
import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.context.annotation.Configuration;
import org.springframework.util.ObjectUtils;
import org.springframework.web.servlet.config.annotation.InterceptorRegistration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import java.util.ArrayList;

/**
 * 日志自动拦截器配置
 *
 * @author gdLiu
 * @date 2025-01-11 20:05
 */
@AutoConfiguration(after = LogConfig.class)
public class LogAutoInterceptorConfig implements WebMvcConfigurer {

    @Resource
    private LogConfig logConfig;
    @Resource
    private RequestLogInterceptor requestLogInterceptor;

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        InterceptorRegistration interceptor = registry.addInterceptor(requestLogInterceptor);
        if (!ObjectUtils.isEmpty(logConfig.getExcludes())) {
            interceptor.excludePathPatterns(new ArrayList<>(logConfig.getExcludes()));
        }
        if (!ObjectUtils.isEmpty(logConfig.getIncludes())) {
            interceptor.addPathPatterns(new ArrayList<>(logConfig.getIncludes()));
        } else {
            interceptor.addPathPatterns("/**");
        }
    }

}
