package com.liu.demo.exception;

import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import java.util.Map;

/**
 * 全局异常处理程序
 *
 * @author gdLiu
 * @date 2025-01-11 19:18
 */
@RestControllerAdvice
public class GlobalExceptionHandler {

    @ExceptionHandler(LogException.class)
    public ResponseEntity<Map<Object, Object>> handleApiException(LogException ex) {
        // 捕获 LogException,返回指定的状态码和信息
        Map<Object, Object> response = Map.of("code", ex.getCode(), "message", ex.getMessage());
        return new ResponseEntity<>(response, HttpStatus.valueOf(ex.getCode()));
    }

    @ExceptionHandler(Exception.class)
    public ResponseEntity<Map<Object, Object>> handleException(Exception ex) {
        // 捕获其他未处理的异常,返回500状态码
        Map<Object, Object> response = Map.of("code", 500, "message", "系统异常:" + ex.getMessage());
        return new ResponseEntity<>(response, HttpStatus.INTERNAL_SERVER_ERROR);
    }

}
